==> flutter_mylibrary-0.3.6.tar.gz: lib/base/provider/request/view_state_request_list_model.dart <==
import 'package:flutter_mylibrary/http/dio_utils.dart';
import 'package:flutter_mylibrary/http/exception/http_error.dart';
import 'package:flutter_mylibrary/utils/utils.dart';

import '../request_info.dart';
import '../view_state_model.dart';

abstract class ViewStateRequestListModel<T> extends ViewStateModel{

  /// 页面数据
  List<T> list = [];

  RequestInfo getRequestInfo();


  onCompleted(List<T> data) {}

  void initData({bool retry = false}) async{
    if (retry) {
      setBusy();
    }
    await getData();
  }


  ///获取数据
  Future<List<T>> getData(){
    RequestInfo requestInfo = getRequestInfo();
    return DioUtils.getInstance().request(
        requestInfo?.method,
        requestInfo?.url,
        data: requestInfo?.data,
        publicMethod: false,
        onFinish: (){
          refreshController.resetRefreshState();
        },
        onError: isInit? null : (e){
          handleError(e);
        }
    ).then((res){
      try{
        if (isNotEmpty(res.data)) {
          list = res.data is List? List<T>.from(res.data.map((e) => requestInfo?.handleRes(e))).toList() : requestInfo?.handleRes(res.data);
        }
        onCompleted(list);
        if (isEmpty(list)) {
          setEmpty();
        }else{
          setIdle();
        }
        return list;
      }catch(e){
        handleError(e);
        return null;
      }
    });
  }


  void handleError(e){
    refreshController.finishRefresh(success: false);
    setError(e, e is HttpError? e.message : e.toString());

  }
}

==> flutter_mylibrary-0.3.32.tar.gz: lib/base/provider/request/view_state_request_list_model.dart <==
import 'package:flutter_mylibrary/http/dio_utils.dart';
import 'package:flutter_mylibrary/http/exception/http_error.dart';
import 'package:flutter_mylibrary/utils/utils.dart';

import '../request_info.dart';
import '../view_state_model.dart';

abstract class ViewStateRequestListModel<T> extends ViewStateModel{

  /// 页面数据
  List<T> list = [];

  RequestInfo getRequestInfo();


  onCompleted(List<T> data) {}

  void initData({bool retry = false}) async{
    if (retry) {
      setBusy();
    }
    await getData();
  }


  ///获取数据
  Future<List<T>> getData(){
    RequestInfo requestInfo = getRequestInfo();
    return DioUtils().request(
        requestInfo?.method,
        requestInfo?.url,
        data: requestInfo?.data,
        publicMethod: false,
        onFinish: (){
          refreshController.resetRefreshState();
        },
        onError: isInit? null : (e){
          handleError(e);
        }
    ).then((res){
      try{
        if (isNotEmpty(res.data)) {
          list = res.data is List? List<T>.from(res.data.map((e) => requestInfo?.handleRes(e))).toList() : requestInfo?.handleRes(res.data);
        }
        onCompleted(list);
        if (isEmpty(list)) {
          setEmpty();
        }else{
          setIdle();
        }
        return list;
      }catch(e){
        handleError(e);
        return null;
      }
    });
  }


  void handleError(e){
    refreshController.finishRefresh(success: false);
    setError(e, e is HttpError? e.message : e.toString());

  }
}
